@@ -32,7 +32,7 @@ char * gnumeric_get_sheet_range (struct spreadsheet *s, int n);
 struct casereader * gnumeric_make_reader (struct spreadsheet *spreadsheet,
 					  const struct spreadsheet_read_options *opts);
 
-void gnumeric_destroy (struct spreadsheet *r);
+void gnumeric_unref (struct spreadsheet *r);
 
 
 #endif
