@@ -31,7 +31,7 @@ struct spreadsheet *ods_probe (const char *filename, bool report_errors);
 struct casereader * ods_make_reader (struct spreadsheet *spreadsheet, 
 				     const struct spreadsheet_read_options *opts);
 
-void ods_destroy (struct spreadsheet *s);
+void ods_unref (struct spreadsheet *s);
 
 
 #endif
