@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2010, 2011 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -84,14 +84,16 @@
    <http://www.gnu.org/licenses/>. */
 
 #include <config.h>
+
 #include "array.h"
+
 #include <limits.h>
 #include <stdlib.h>
 #include <string.h>
-#include <libpspp/assertion.h>
+#include "libpspp/assertion.h"
 
-#include "xalloc.h"
-#include "minmax.h"
+#include "gl/xalloc.h"
+#include "gl/minmax.h"
 
 /* Finds an element in ARRAY, which contains COUNT elements of
    SIZE bytes each, using COMPARE for comparisons.  Returns the
@@ -370,7 +372,7 @@ insert_range (void *array_, size_t count, size_t size,
 /* Makes room for a new element at IDX in ARRAY, which initially
    consists of COUNT elements of SIZE bytes each, by shifting
    elements IDX...COUNT (exclusive) to the right by one
-   positions. */
+   position. */
 void
 insert_element (void *array, size_t count, size_t size,
                 size_t idx)
@@ -638,7 +640,7 @@ typedef struct
 
 void
 sort (void *array, size_t count, size_t size,
-	    algo_compare_func *compare, const void *aux)
+      algo_compare_func *compare, const void *aux)
 {
   char *const first = array;
   const size_t max_thresh = MAX_THRESH * size;
