@@ -1,5 +1,5 @@
 /* PSPP - a program for statistical analysis.
-   Copyright (C) 1997-9, 2000, 2006, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (C) 1997-9, 2000, 2006, 2010, 2011, 2014 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -93,6 +93,8 @@ void msg_destroy(struct msg *);
 char *msg_to_string (const struct msg *, const char *command_name);
 
 /* Emitting messages. */
+void vmsg (enum msg_class class, const char *format, va_list args)
+     PRINTF_FORMAT (2, 0);
 void msg (enum msg_class, const char *format, ...)
      PRINTF_FORMAT (2, 3);
 void msg_emit (struct msg *);
