@@ -108,7 +108,7 @@ struct _PsppSheetView
 {
   GtkContainer parent;
 
-  PsppSheetViewPrivate *GSEAL (priv);
+  PsppSheetViewPrivate *PSEAL (priv);
 
   gboolean dispose_has_run ;
 };
@@ -316,8 +316,6 @@ gboolean               pspp_sheet_view_get_dest_row_at_pos           (PsppSheetV
 								    gint                       drag_y,
 								    GtkTreePath              **path,
 								    PsppSheetViewDropPosition   *pos);
-GdkPixmap             *pspp_sheet_view_create_row_drag_icon          (PsppSheetView               *tree_view,
-								    GtkTreePath               *path);
 
 /* Interactive search */
 void                       pspp_sheet_view_set_enable_search     (PsppSheetView                *tree_view,
