@@ -51,7 +51,7 @@ append_fragment (GString *string, const gchar *cut, PsppireVarView *vv)
 }
 
 static char *
-generate_syntax (PsppireDialogAction *act)
+generate_syntax (const PsppireDialogAction *act)
 {
   PsppireDialogActionRuns *rd = PSPPIRE_DIALOG_ACTION_RUNS (act);
   gchar *text;
@@ -128,12 +128,19 @@ refresh (PsppireDialogAction *rd_)
 }
 
 static void
-psppire_dialog_action_runs_activate (GtkAction *a)
+psppire_dialog_action_runs_activate (PsppireDialogAction *a)
 {
   PsppireDialogAction *pda = PSPPIRE_DIALOG_ACTION (a);
   PsppireDialogActionRuns *act = PSPPIRE_DIALOG_ACTION_RUNS (a);
 
-  GtkBuilder *xml = builder_new ("runs.ui");
+  GHashTable *thing = psppire_dialog_action_get_hash_table (pda);
+  GtkBuilder *xml = g_hash_table_lookup (thing, a);
+  if (!xml)
+    {
+      xml = builder_new ("runs.ui");
+      g_hash_table_insert (thing, a, xml);
+    }
+
   pda->dialog = get_widget_assert   (xml, "runs-dialog");
   pda->source = get_widget_assert   (xml, "dict-view");
 
@@ -144,12 +151,9 @@ psppire_dialog_action_runs_activate (GtkAction *a)
   act->cb[CB_CUSTOM] = get_widget_assert (xml, "checkbutton3");
   act->variables = get_widget_assert   (xml, "psppire-var-view1");
 
-
   psppire_dialog_action_set_valid_predicate (pda, dialog_state_valid);
   psppire_dialog_action_set_refresh (pda, refresh);
 
-  g_object_unref (xml);
-
   if (PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_runs_parent_class)->activate)
     PSPPIRE_DIALOG_ACTION_CLASS (psppire_dialog_action_runs_parent_class)->activate (pda);
 }
@@ -157,9 +161,7 @@ psppire_dialog_action_runs_activate (GtkAction *a)
 static void
 psppire_dialog_action_runs_class_init (PsppireDialogActionRunsClass *class)
 {
-  GtkActionClass *action_class = GTK_ACTION_CLASS (class);
-
-  action_class->activate = psppire_dialog_action_runs_activate;
+  psppire_dialog_action_set_activation (class, psppire_dialog_action_runs_activate);
   PSPPIRE_DIALOG_ACTION_CLASS (class)->generate_syntax = generate_syntax;
 }
 
