@@ -36,8 +36,8 @@
 #include "ui/gui/psppire-encoding-selector.h"
 #include "ui/gui/psppire-lex-reader.h"
 #include "ui/gui/psppire-syntax-window.h"
-#include "ui/gui/psppire-window-register.h"
 #include "ui/gui/psppire.h"
+#include "ui/gui/windows-menu.h"
 
 #include "gl/localcharset.h"
 #include "gl/xalloc.h"
@@ -296,7 +296,7 @@ clipboard_get_cb (GtkClipboard     *clipboard,
   PsppireSyntaxWindow *sw = data;
   g_assert (info == SELECT_FMT_TEXT);
 
-  gtk_selection_data_set (selection_data, selection_data->target,
+  gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data),
 			  8,
 			  (const guchar *) sw->cliptext, strlen (sw->cliptext));
 
@@ -369,7 +369,6 @@ on_edit_copy (PsppireSyntaxWindow *sw)
   set_clip (sw, &begin, &end);
 }
 
-
 static void
 on_edit_paste (PsppireSyntaxWindow *sw)
 {
@@ -566,8 +565,8 @@ syntax_pick_filename (PsppireWindow *window)
     gtk_file_chooser_dialog_new (_("Save Syntax"),
 				 GTK_WINDOW (se),
 				 GTK_FILE_CHOOSER_ACTION_SAVE,
-				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				 GTK_STOCK_SAVE,   GTK_RESPONSE_ACCEPT,
+				 _("Cancel"), GTK_RESPONSE_CANCEL,
+				 _("Save"),   GTK_RESPONSE_ACCEPT,
 				 NULL);
 
   g_object_set (dialog, "local-only", FALSE, NULL);
@@ -698,7 +697,7 @@ static void
 psppire_syntax_window_init (PsppireSyntaxWindow *window)
 {
   GtkBuilder *xml = builder_new ("syntax-editor.ui");
-  GtkWidget *box = gtk_vbox_new (FALSE, 0);
+  GtkWidget *box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   GtkWidget *menubar = get_widget_assert (xml, "menubar");
   GtkWidget *sw = get_widget_assert (xml, "scrolledwindow8");
@@ -860,22 +859,11 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
 		    G_CALLBACK (on_run_to_end),
 		    window);
 
-  g_signal_connect (get_action_assert (xml,"windows_minimise_all"),
-		    "activate",
-		    G_CALLBACK (psppire_window_minimise_all), NULL);
+  gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
+			 create_windows_menu (GTK_WINDOW (window)));
 
-
-
-
-
-  {
-  GtkUIManager *uim = GTK_UI_MANAGER (get_object_assert (xml, "uimanager1", GTK_TYPE_UI_MANAGER));
-
-  merge_help_menu (uim);
-
-  PSPPIRE_WINDOW (window)->menu =
-    GTK_MENU_SHELL (gtk_ui_manager_get_widget (uim,"/ui/menubar/windows/windows_minimise_all")->parent);
-  }
+  gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
+			 create_help_menu (GTK_WINDOW (window)));
 
   g_object_unref (xml);
 }
