@@ -296,7 +296,7 @@ static void range_set (PsppireValChooser *vr, struct old_value *ov, const struct
 
 static GtkWidget * range_entry (struct layout *l, struct range_widgets *rw)
 {
-  GtkWidget *vbox = gtk_vbox_new (3, FALSE);
+  GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
   GtkWidget *entrylo = gtk_entry_new ();
   GtkWidget *label = gtk_label_new (_("through"));
   GtkWidget *entryhi = gtk_entry_new ();
@@ -304,7 +304,11 @@ static GtkWidget * range_entry (struct layout *l, struct range_widgets *rw)
   rw->e1 = GTK_ENTRY (entrylo);
   rw->e2 = GTK_ENTRY (entryhi);
 
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  g_object_set (G_OBJECT (label),
+		"valign", GTK_ALIGN_CENTER,
+		"halign", GTK_ALIGN_START,
+		NULL);
+		
 
   g_signal_connect (vbox, "notify::sensitive", G_CALLBACK (focus_follows_sensitivity), entrylo);
 
@@ -340,13 +344,15 @@ static void
 psppire_val_chooser_init (PsppireValChooser *vr)
 {
   gint i;
-  GtkWidget *aln = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-  GtkWidget *table = gtk_table_new (11, 2, FALSE);
+  GtkWidget *grid = gtk_grid_new ();
   GSList *group = NULL;
   gint row = 0;
 
-  gtk_alignment_set_padding (GTK_ALIGNMENT (aln), 0, 0, 5, 5);
-
+  g_object_set (G_OBJECT (grid),
+		"margin-start", 5,
+		"margin-end", 5,
+		NULL);
+  
   vr->input_var_is_string = FALSE;
 
   for (i = 0; i < n_VAL_CHOOSER_BUTTONS; ++i)
@@ -357,21 +363,26 @@ psppire_val_chooser_init (PsppireValChooser *vr)
       vr->rw[i].rb = GTK_TOGGLE_BUTTON (gtk_radio_button_new (group));
       gtk_label_set_mnemonic_widget (vr->rw[i].label, GTK_WIDGET (vr->rw[i].rb));
 
-      gtk_misc_set_alignment (GTK_MISC (vr->rw[i].label), 0, 0.5);
+      g_object_set (G_OBJECT (vr->rw[i].label),
+		    "valign", GTK_ALIGN_CENTER,
+		    "halign", GTK_ALIGN_START,
+		    NULL);
 
       group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (vr->rw[i].rb));
 
       /* Attach the buttons */
-      gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (vr->rw[i].rb),
-			0, 1,	row, row + 1,
-			0, GTK_EXPAND | GTK_FILL,
-			0, 0);
+      gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (vr->rw[i].rb),
+		       0, row, 1, 1);
 
+      gtk_widget_set_hexpand (GTK_WIDGET (vr->rw[i].rb), FALSE);
+      
       /* Attach the labels */
-      gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (vr->rw[i].label),
-			1, 2,   row, row + 1,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL,
-			0, 0);
+      gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (vr->rw[i].label),
+			1, row, 1, 1);
+
+      gtk_widget_set_hexpand (GTK_WIDGET (vr->rw[i].label), TRUE);
+
+      
       ++row;
 
       if (l->fill)
@@ -380,8 +391,10 @@ psppire_val_chooser_init (PsppireValChooser *vr)
 
 	  gtk_widget_set_sensitive (fill, FALSE);
 
-	  gtk_table_attach_defaults (GTK_TABLE (table), fill, 1, 2,
-				 row, row + 1);
+	  gtk_grid_attach (GTK_GRID (grid), fill, 1, row, 1, 1);
+
+	  gtk_widget_set_hexpand (fill, TRUE);
+	  
 	  ++row;
 
       	  g_signal_connect (vr->rw[i].rb, "toggled", G_CALLBACK (set_sensitivity_from_toggle), fill);
@@ -390,10 +403,9 @@ psppire_val_chooser_init (PsppireValChooser *vr)
 
   gtk_frame_set_shadow_type (GTK_FRAME (vr), GTK_SHADOW_ETCHED_IN);
 
-  gtk_container_add (GTK_CONTAINER (aln), table);
-  gtk_container_add (GTK_CONTAINER (vr), aln);
+  gtk_container_add (GTK_CONTAINER (vr), grid);
 
-  gtk_widget_show_all (aln);
+  gtk_widget_show_all (grid);
 }
 
 
